@@ -3,8 +3,10 @@
 import os
 import math
 from enum import Enum
+from csv import reader
 
 __string_delim = '~'
+__datasheet_delim = '~'
 __opt_string_delim = '\t'
 delim_escape = '&TLD;'
 
@@ -369,3 +371,49 @@ def get_run_type(file_name : str):
 		ret = 2
 	return ret
 
+def create_data_sheet(datasheet_name : str, rows : list[list]):
+	"""Generates a single data sheet from a list of lists
+
+	:param datasheet_name: name of the data sheet - must replace one in the model
+	:type datasheet_name: str
+	:param rows: values
+	:type rows: list[list]
+	"""
+	
+	ret = [[datasheet_name]]
+	
+	ret.extend([__datasheet_delim.join([str(v) for v in r]) for r in rows])
+	if(len(rows) > 0):
+		count = len(rows[0])
+		ret[0].extend(['' for _ in range(0, count-1)])
+		ret[0] = __datasheet_delim.join(ret[0])
+	return ret
+
+def create_data_sheet_from_csv(file_path : str):
+	"""Generates a data sheets from a CSV file
+
+	Can create one or many data sheets.
+
+	Format:
+	<Name1>
+	<Values>*
+	<Name2>
+	<Values>*
+
+	No blank lines in file
+
+	:param file_path: name of path containing the data
+	:type file_path: str
+	"""
+	with open(file_path, newline='') as f:
+		values = reader(f)
+		data = list(values)
+	
+	starts = [ index for index, line in enumerate(data) if len(line) == 1]
+	starts.append(None)
+	
+	bounds = [(s, f if (f == None)  else f) for s,f in zip(starts, starts[1:])]
+	ret = [create_data_sheet(data[s][0], data[s+1:f]) for s, f in bounds]
+
+	return ret
+
